==> alg-feature-0.0.1-20200608.092458-8-sources.jar: cn/com/duiba/nezha/alg/feature/vo/BaiDuFeature.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import java.io.Serializable;

public class BaiDuFeature implements Serializable {

    private static final long serialVersionUID = 2784377246455148485L;

    private String title;//视频标题
    private String url;//视频关键词
    private Integer contentLength;//视频时长
    private Integer channelId;//频道信息id
    private String province;//省份id
    private String city;//城市id
    private String district;//地区id
    private String street;//街道id
    private Integer adSlotType;//广告类型，创意类型id
    private Integer pageType;//页面类型

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public Integer getContentLength() {
        return contentLength;
    }

    public void setContentLength(Integer contentLength) {
        this.contentLength = contentLength;
    }

    public Integer getChannelId() {
        return channelId;
    }

    public void setChannelId(Integer channelId) {
        this.channelId = channelId;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public String getStreet() {
        return street;
    }

    public void setStreet(String street) {
        this.street = street;
    }

    public Integer getAdSlotType() {
        return adSlotType;
    }

    public void setAdSlotType(Integer adSlotType) {
        this.adSlotType = adSlotType;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }
}

==> alg-feature-2.8.6755-20220328.021647-1-sources.jar: cn/com/duiba/nezha/alg/feature/vo/BaiDuFeature.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import java.io.Serializable;

public class BaiDuFeature implements Serializable {

    private static final long serialVersionUID = 2784377246455148485L;

    private String title;//视频标题
    private String url;//视频关键词
    private Integer contentLength;//视频时长
    private Integer channelId;//频道信息id
    private String province;//省份id
    private String city;//城市id
    private String district;//地区id
    private String street;//街道id
    private Integer adSlotType;//广告类型，创意类型id
//    private Integer pageType;//页面类型
//    private String userTagIdList;//用户意图词信息

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public Integer getContentLength() {
        return contentLength;
    }

    public void setContentLength(Integer contentLength) {
        this.contentLength = contentLength;
    }

    public Integer getChannelId() {
        return channelId;
    }

    public void setChannelId(Integer channelId) {
        this.channelId = channelId;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public String getStreet() {
        return street;
    }

    public void setStreet(String street) {
        this.street = street;
    }

    public Integer getAdSlotType() {
        return adSlotType;
    }

    public void setAdSlotType(Integer adSlotType) {
        this.adSlotType = adSlotType;
    }

//    public Integer getPageType() {
//        return pageType;
//    }
//
//    public void setPageType(Integer pageType) {
//        this.pageType = pageType;
//    }
//
//    public String getUserTagIdList() { return userTagIdList; }
//
//    public void setUserTagIdList(String userTagIdList) { this.userTagIdList = userTagIdList; }
}
